build_personal_folders

Function build_personal_folders 

fn build_personal_folders(
    names: Vec<String>,
    target: Option<(FolderId, &str)>,
) -> Vec<FolderView>
Builds the folder views to import. When a target folder is given it becomes folder 0 and the imported groups are nested beneath it as "{target}/{group}".